@@ -1,4 +1,4 @@
-from .__util import DF, Period
+from adasher.data_utils.__util import DF, Period
 
 
 def time_period(dt1, dt2, name):
